# coding: utf-8

"""
    CMS Site Search

    Use these endpoints for searching content on your HubSpot hosted CMS website(s).  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.site_search.configuration import Configuration


class IndexedField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"values": "list[object]", "name": "str", "value": "object", "metadata_field": "bool"}

    attribute_map = {"values": "values", "name": "name", "value": "value", "metadata_field": "metadataField"}

    def __init__(self, values=None, name=None, value=None, metadata_field=None, local_vars_configuration=None):  # noqa: E501
        """IndexedField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._values = None
        self._name = None
        self._value = None
        self._metadata_field = None
        self.discriminator = None

        self.values = values
        self.name = name
        self.value = value
        self.metadata_field = metadata_field

    @property
    def values(self):
        """Gets the values of this IndexedField.  # noqa: E501


        :return: The values of this IndexedField.  # noqa: E501
        :rtype: list[object]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this IndexedField.


        :param values: The values of this IndexedField.  # noqa: E501
        :type values: list[object]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values

    @property
    def name(self):
        """Gets the name of this IndexedField.  # noqa: E501


        :return: The name of this IndexedField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndexedField.


        :param name: The name of this IndexedField.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def value(self):
        """Gets the value of this IndexedField.  # noqa: E501


        :return: The value of this IndexedField.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this IndexedField.


        :param value: The value of this IndexedField.  # noqa: E501
        :type value: object
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def metadata_field(self):
        """Gets the metadata_field of this IndexedField.  # noqa: E501


        :return: The metadata_field of this IndexedField.  # noqa: E501
        :rtype: bool
        """
        return self._metadata_field

    @metadata_field.setter
    def metadata_field(self, metadata_field):
        """Sets the metadata_field of this IndexedField.


        :param metadata_field: The metadata_field of this IndexedField.  # noqa: E501
        :type metadata_field: bool
        """
        if self.local_vars_configuration.client_side_validation and metadata_field is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata_field`, must not be `None`")  # noqa: E501

        self._metadata_field = metadata_field

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndexedField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IndexedField):
            return True

        return self.to_dict() != other.to_dict()
